@@ -1,10 +1,12 @@
 """Rule definition for JSON Schema Validations."""
+from __future__ import annotations
+
 import json
 import logging
 import os
 import sys
 from functools import lru_cache
-from typing import Any, List
+from typing import Any
 
 import yaml
 from jsonschema import validate
@@ -13,6 +15,7 @@ from jsonschema.exceptions import ValidationError
 from ansiblelint.config import JSON_SCHEMAS
 from ansiblelint.errors import MatchError
 from ansiblelint.file_utils import Lintable
+from ansiblelint.loaders import yaml_load_safe
 from ansiblelint.rules import AnsibleLintRule
 from ansiblelint.schemas import __file__ as schemas_module
 
@@ -51,7 +54,7 @@ class ValidateSchemaRule(AnsibleLintRule):
         with open(schema_file, encoding="utf-8") as f:
             return json.load(f)
 
-    def matchyaml(self, file: Lintable) -> List[MatchError]:
+    def matchyaml(self, file: Lintable) -> list[MatchError]:
         """Return JSON validation errors found as a list of MatchError(s)."""
         result = []
         if file.kind not in JSON_SCHEMAS:
@@ -59,7 +62,7 @@ class ValidateSchemaRule(AnsibleLintRule):
 
         try:
             # convert yaml to json (keys are converted to strings)
-            yaml_data = yaml.safe_load(file.content)
+            yaml_data = yaml_load_safe(file.content)
             json_data = json.loads(json.dumps(yaml_data))
             validate(
                 instance=json_data,
@@ -103,7 +106,7 @@ if "pytest" in sys.modules:
             (
                 "examples/roles/invalid_requirements_schema/meta/requirements.yml",
                 "requirements",
-                ["'collections' is a required property"],
+                ["{'foo': 'bar'} is not valid under any of the given schemas"],
             ),
             (
                 "examples/roles/invalid_meta_schema/meta/main.yml",
@@ -198,7 +201,7 @@ if "pytest" in sys.modules:
             "argspecs-broken",
         ),
     )
-    def test_schema(file: str, expected_kind: str, expected: List[str]) -> None:
+    def test_schema(file: str, expected_kind: str, expected: list[str]) -> None:
         """Validate parsing of ansible output."""
         lintable = Lintable(file)
         assert lintable.kind == expected_kind
